// Bspl058.cs

using System;

public abstract class Form {

	private int farbe;
	public const int ROT = 1;
	public const int GRUEN = 2;
	public const int BLAU = 4;

	public int Farbe {
		get {
			return farbe;
		}
		set {
			if (value < 8)
				farbe = value;
		}
	}

	public string FarbeToString() {
		switch(farbe) {
			case 0:
				return "schwarz";
			case 1:
				return "rot";
			case 2:
				return "grn";
			case 3:
				return "gelb";
			case 4:
				return "blau";
			case 5:
				return "magenta";
			case 6:
				return "cyan";
			case 7:
				return "wei";
			default:
				return "unbekannt";
		}
	}

	virtual public double Flaeche {
		get {
			return 0;
		}
	}
}

public class Kreis : Form {

	protected int r;

	public Kreis(int r) {
		this.r = r;
	}

	public Kreis() {}

	override public double Flaeche {
		get {
			return Math.PI * Math.Pow(r,2);
		}
	}
}

public sealed class Ring : Kreis {

	private double l;

	public Ring(int r, double l) {
		this.r = r;
		this.l = l;
	}

	override public double Flaeche {
		get {
			return base.Flaeche
				- Math.PI * Math.Pow(l,2);
		}
	}
}

public class Rechteck : Form {

	private int a, b;

	public Rechteck(int a, int b) {
		this.a = a;
		this.b = b;
	}

	new public double Flaeche {
		get {
			return a*b;
		}
	}
}

public class Bspl058 {	

	public static void Main() {
		Form[] liste = new Form[5];
		liste[0] = new Ring(10,5);
		liste[1] = new Kreis(4);
		liste[2] = new Ring(5,2);
		liste[3] = new Rechteck(4,3);
		liste[4] = new Rechteck(10,5);

		for (int i=0; i<liste.Length; i++)
			Console.WriteLine(liste[i].ToString() 
				+ ": " + liste[i].Flaeche);

	}
}
